@@ -15,6 +15,7 @@
 #include <qcursor.h>
 #include <qpixmap.h>
 #include <qpainter.h>
+#include <private/qpixmap_win_p.h>
 #include <qobject.h>
 #include <qdebug.h>
 #ifdef QAX_SERVER
@@ -94,9 +95,6 @@ static QFont IFontToQFont(IFont *f)
     return font;
 }
 
-Q_GUI_EXPORT HBITMAP qt_pixmapToWinHBITMAP(const QPixmap &p, int hbitmapFormat = 0);
-Q_GUI_EXPORT QPixmap qt_pixmapFromWinHBITMAP(HBITMAP bitmap, int hbitmapFormat = 0);
-
 static IPictureDisp *QPixmapToIPicture(const QPixmap &pixmap)
 {
     IPictureDisp *pic = nullptr;
@@ -240,7 +238,7 @@ bool QVariantToVARIANT(const QVariant &var, VARIANT &arg, const QByteArray &type
         return QVariantToVARIANT(var, *arg.pvarVal, typeName, false);
     }
 
-    if (out && proptype == QMetaType::User && typeName == "QVariant") {
+    if (out && proptype == QMetaType::QVariant) {
         VARIANT *pVariant = new VARIANT;
         QVariantToVARIANT(var, *pVariant, QByteArray(), false);
         arg.vt = VT_VARIANT|VT_BYREF;
